pub enum DispatchGraph {
Flex(BackendGraph<Flex>),
}Expand description
A captured graph from one of the dispatched backends (see
BackendTypes::GraphPrimitive).
Like DispatchTensorKind, one variant per enabled backend: the graph is
captured by, and can only replay on, the backend it was recorded on.
Variants
Flex(BackendGraph<Flex>)
Available on
default_backend or crate feature flex only.A graph captured on the Flex backend.