pub enum DispatchTensor {
NdArray(BackendTensor<NdArray>),
}Expand description
Dispatch tensor that can hold tensors from any enabled backend.
This enum wraps backend-specific tensor types, allowing runtime selection of the backend to execute operations on.
Variants