pub struct DispatchTensor { /* private fields */ }Expand description
A tensor that can dispatch operations to any enabled backend at runtime.
When the autodiff feature is enabled, tensors may carry a checkpointing
strategy used to control gradient computation. This is derived from the
device used to create the tensor.