Module tensor

Module tensor 

Dispatch tensor module.

Structs

DispatchTensor
A tensor that can dispatch operations to any enabled backend at runtime.

Enums

BackendTensor
Tensor which points to a backend tensor primitive kind.
DispatchTensorKind
Internal representation of a DispatchTensor.

Traits

DispatchKindConversion
Trait to execute runtime routing conversions between the dynamic dispatch layer and specific backends.