pub struct DispatchTensor {
pub kind: DispatchTensorKind,
pub checkpointing: Option<CheckpointingStrategy>,
}Expand description
A tensor that can dispatch operations to any enabled backend at runtime.
When the autodiff feature is enabled, tensors may carry a checkpointing
strategy used to control gradient computation. This is derived from the
device used to create the tensor.
Fields
kind: DispatchTensorKindTensor kind primitive.
checkpointing: Option<CheckpointingStrategy>Holds the autodiff checkpointing strategy.
None: tensor is not tracked by autodiffSome(strategy): tensor is tracked by autodiff, and uses the checkpointingstrategy